@@ -31,15 +31,14 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.TreeMap;
 import java.util.TreeSet;
 
 import org.apache.maven.artifact.Artifact;
-import org.apache.maven.artifact.factory.ArtifactFactory;
-import org.apache.maven.artifact.resolver.ArtifactNotFoundException;
-import org.apache.maven.artifact.resolver.ArtifactResolutionException;
-import org.apache.maven.artifact.resolver.ArtifactResolver;
+import org.apache.maven.artifact.resolver.ArtifactResolutionRequest;
+import org.apache.maven.artifact.resolver.ArtifactResolutionResult;
 import org.apache.maven.plugin.descriptor.DuplicateParameterException;
 import org.apache.maven.plugin.descriptor.InvalidParameterException;
 import org.apache.maven.plugin.descriptor.InvalidPluginDescriptorException;
@@ -47,6 +46,7 @@ import org.apache.maven.plugin.descriptor.MojoDescriptor;
 import org.apache.maven.plugin.descriptor.PluginDescriptor;
 import org.apache.maven.plugin.descriptor.Requirement;
 import org.apache.maven.project.MavenProject;
+import org.apache.maven.repository.RepositorySystem;
 import org.apache.maven.tools.plugin.ExtendedMojoDescriptor;
 import org.apache.maven.tools.plugin.PluginToolsRequest;
 import org.apache.maven.tools.plugin.extractor.ExtractionException;
@@ -59,6 +59,7 @@ import org.apache.maven.tools.plugin.extractor.annotations.scanner.MojoAnnotated
 import org.apache.maven.tools.plugin.extractor.annotations.scanner.MojoAnnotationsScanner;
 import org.apache.maven.tools.plugin.extractor.annotations.scanner.MojoAnnotationsScannerRequest;
 import org.apache.maven.tools.plugin.util.PluginUtils;
+import org.codehaus.plexus.archiver.ArchiverException;
 import org.codehaus.plexus.archiver.UnArchiver;
 import org.codehaus.plexus.archiver.manager.ArchiverManager;
 import org.codehaus.plexus.archiver.manager.NoSuchArchiverException;
@@ -89,14 +90,12 @@ public class JavaAnnotationsMojoDescriptorExtractor
     private MojoAnnotationsScanner mojoAnnotationsScanner;
 
     @org.codehaus.plexus.component.annotations.Requirement
-    private ArtifactResolver artifactResolver;
-
-    @org.codehaus.plexus.component.annotations.Requirement
-    private ArtifactFactory artifactFactory;
+    private RepositorySystem repositorySystem;
 
     @org.codehaus.plexus.component.annotations.Requirement
     private ArchiverManager archiverManager;
 
+    @Override
     public List<MojoDescriptor> execute( PluginToolsRequest request )
         throws ExtractionException, InvalidPluginDescriptorException
     {
@@ -137,7 +136,7 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
         for ( MojoAnnotatedClass mojoAnnotatedClass : mojoAnnotatedClasses )
         {
-            if ( StringUtils.equals( mojoAnnotatedClass.getArtifact().getArtifactId(),
+            if ( Objects.equals( mojoAnnotatedClass.getArtifact().getArtifactId(),
                                      request.getProject().getArtifact().getArtifactId() ) )
             {
                 continue;
@@ -201,10 +200,21 @@ public class JavaAnnotationsMojoDescriptorExtractor
         try
         {
             Artifact sourcesArtifact =
-                artifactFactory.createArtifactWithClassifier( artifact.getGroupId(), artifact.getArtifactId(),
-                                                              artifact.getVersion(), artifact.getType(), classifier );
+                repositorySystem.createArtifactWithClassifier( artifact.getGroupId(), artifact.getArtifactId(),
+                                                               artifact.getVersion(), artifact.getType(), classifier );
 
-            artifactResolver.resolve( sourcesArtifact, request.getRemoteRepos(), request.getLocal() );
+            ArtifactResolutionRequest req = new ArtifactResolutionRequest();
+            req.setArtifact( sourcesArtifact );
+            req.setLocalRepository( request.getLocal() );
+            req.setRemoteRepositories( request.getRemoteRepos() );
+            ArtifactResolutionResult res = repositorySystem.resolve( req );
+            if ( res.hasMissingArtifacts() || res.hasExceptions() )
+            {
+                getLogger().warn(
+                    "Unable to get sources artifact for " + artifact.getGroupId() + ":" + artifact.getArtifactId() + ":"
+                    + artifact.getVersion() + ". Some javadoc tags (@since, @deprecated and comments) won't be used" );
+                return Collections.emptyMap();
+            }
 
             if ( sourcesArtifact.getFile() == null || !sourcesArtifact.getFile().exists() )
             {
@@ -224,23 +234,10 @@ public class JavaAnnotationsMojoDescriptorExtractor
             unArchiver.setDestDirectory( extractDirectory );
             unArchiver.extract();
 
-            return discoverClasses( request.getEncoding(), Arrays.asList( extractDirectory ), 
+            return discoverClasses( request.getEncoding(), Arrays.asList( extractDirectory ),
                                     request.getDependencies() );
         }
-        catch ( ArtifactResolutionException e )
-        {
-            throw new ExtractionException( e.getMessage(), e );
-        }
-        catch ( ArtifactNotFoundException e )
-        {
-            //throw new ExtractionException( e.getMessage(), e );
-            getLogger().debug( "skip ArtifactNotFoundException:" + e.getMessage() );
-            getLogger().warn(
-                "Unable to get sources artifact for " + artifact.getGroupId() + ":" + artifact.getArtifactId() + ":"
-                    + artifact.getVersion() + ". Some javadoc tags (@since, @deprecated and comments) won't be used" );
-            return Collections.emptyMap();
-        }
-        catch ( NoSuchArchiverException e )
+        catch ( ArchiverException | NoSuchArchiverException e )
         {
             throw new ExtractionException( e.getMessage(), e );
         }
@@ -248,9 +245,6 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
     /**
      * from sources scan to get @since and @deprecated and description of classes and fields.
-     *
-     * @param mojoAnnotatedClasses
-     * @param javaClassesMap
      */
     protected void populateDataFromJavadoc( Map<String, MojoAnnotatedClass> mojoAnnotatedClasses,
                                             Map<String, JavaClass> javaClassesMap )
@@ -287,8 +281,7 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
             // populate parameters
             Map<String, ParameterAnnotationContent> parameters =
-                getParametersParentHierarchy( entry.getValue(), new HashMap<String, ParameterAnnotationContent>(),
-                                              mojoAnnotatedClasses );
+                    getParametersParentHierarchy( entry.getValue(), mojoAnnotatedClasses );
             parameters = new TreeMap<>( parameters );
             for ( Map.Entry<String, ParameterAnnotationContent> parameter : parameters.entrySet() )
             {
@@ -351,19 +344,27 @@ public class JavaAnnotationsMojoDescriptorExtractor
      */
     private DocletTag findInClassHierarchy( JavaClass javaClass, String tagName )
     {
-        DocletTag tag = javaClass.getTagByName( tagName );
-
-        if ( tag == null )
+        try
         {
-            JavaClass superClass = javaClass.getSuperJavaClass();
+            DocletTag tag = javaClass.getTagByName( tagName );
 
-            if ( superClass != null )
+            if ( tag == null )
             {
-                tag = findInClassHierarchy( superClass, tagName );
-            }
-        }
+                JavaClass superClass = javaClass.getSuperJavaClass();
 
-        return tag;
+                if ( superClass != null )
+                {
+                    tag = findInClassHierarchy( superClass, tagName );
+                }
+            }
+
+            return tag;
+        }
+        catch ( NoClassDefFoundError e )
+        {
+            getLogger().warn( "Failed extracting tag '" + tagName + "' from class " + javaClass );
+            throw e;
+        }
     }
 
     /**
@@ -375,37 +376,45 @@ public class JavaAnnotationsMojoDescriptorExtractor
     private Map<String, JavaField> extractFieldParameterTags( JavaClass javaClass,
                                                               Map<String, JavaClass> javaClassesMap )
     {
-        Map<String, JavaField> rawParams = new TreeMap<String, com.thoughtworks.qdox.model.JavaField>();
-
-        // we have to add the parent fields first, so that they will be overwritten by the local fields if
-        // that actually happens...
-        JavaClass superClass = javaClass.getSuperJavaClass();
-
-        if ( superClass != null )
+        try
         {
-            if ( superClass.getFields().size() > 0 )
-            {
-                rawParams = extractFieldParameterTags( superClass, javaClassesMap );
-            }
-            // maybe sources comes from scan of sources artifact
-            superClass = javaClassesMap.get( superClass.getFullyQualifiedName() );
+            Map<String, JavaField> rawParams = new TreeMap<>();
+
+            // we have to add the parent fields first, so that they will be overwritten by the local fields if
+            // that actually happens...
+            JavaClass superClass = javaClass.getSuperJavaClass();
+
             if ( superClass != null )
             {
-                rawParams = extractFieldParameterTags( superClass, javaClassesMap );
+                if ( superClass.getFields().size() > 0 )
+                {
+                    rawParams = extractFieldParameterTags( superClass, javaClassesMap );
+                }
+                // maybe sources comes from scan of sources artifact
+                superClass = javaClassesMap.get( superClass.getFullyQualifiedName() );
+                if ( superClass != null )
+                {
+                    rawParams = extractFieldParameterTags( superClass, javaClassesMap );
+                }
             }
-        }
-        else
-        {
+            else
+            {
 
-            rawParams = new TreeMap<>();
-        }
+                rawParams = new TreeMap<>();
+            }
 
-        for ( JavaField field : javaClass.getFields() )
+            for ( JavaField field : javaClass.getFields() )
+            {
+                rawParams.put( field.getName(), field );
+            }
+
+            return rawParams;
+        }
+        catch ( NoClassDefFoundError e )
         {
-            rawParams.put( field.getName(), field );
+            getLogger().warn( "Failed extracting parameters from " + javaClass );
+            throw e;
         }
-        
-        return rawParams;
     }
 
     protected Map<String, JavaClass> discoverClasses( final PluginToolsRequest request )
@@ -413,12 +422,11 @@ public class JavaAnnotationsMojoDescriptorExtractor
         return discoverClasses( request.getEncoding(), request.getProject() );
     }
 
-    @SuppressWarnings( "unchecked" )
     protected Map<String, JavaClass> discoverClasses( final String encoding, final MavenProject project )
     {
         List<File> sources = new ArrayList<>();
 
-        for ( String source : (List<String>) project.getCompileSourceRoots() )
+        for ( String source : project.getCompileSourceRoots() )
         {
             sources.add( new File( source ) );
         }
@@ -543,8 +551,7 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
             // Parameter annotations
             Map<String, ParameterAnnotationContent> parameters =
-                getParametersParentHierarchy( mojoAnnotatedClass, new HashMap<String, ParameterAnnotationContent>(),
-                                              mojoAnnotatedClasses );
+                    getParametersParentHierarchy( mojoAnnotatedClass, mojoAnnotatedClasses );
 
             for ( ParameterAnnotationContent parameterAnnotationContent : new TreeSet<>( parameters.values() ) )
             {
@@ -577,8 +584,7 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
             // Component annotations
             Map<String, ComponentAnnotationContent> components =
-                getComponentsParentHierarchy( mojoAnnotatedClass, new HashMap<String, ComponentAnnotationContent>(),
-                                              mojoAnnotatedClasses );
+                    getComponentsParentHierarchy( mojoAnnotatedClass, mojoAnnotatedClasses );
 
             for ( ComponentAnnotationContent componentAnnotationContent : new TreeSet<>( components.values() ) )
             {
@@ -644,8 +650,8 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
 
     protected Map<String, ParameterAnnotationContent> getParametersParentHierarchy(
-        MojoAnnotatedClass mojoAnnotatedClass, Map<String, ParameterAnnotationContent> parameters,
-        Map<String, MojoAnnotatedClass> mojoAnnotatedClasses )
+            MojoAnnotatedClass mojoAnnotatedClass,
+            Map<String, MojoAnnotatedClass> mojoAnnotatedClasses )
     {
         List<ParameterAnnotationContent> parameterAnnotationContents = new ArrayList<>();
 
@@ -682,8 +688,8 @@ public class JavaAnnotationsMojoDescriptorExtractor
     }
 
     protected Map<String, ComponentAnnotationContent> getComponentsParentHierarchy(
-        MojoAnnotatedClass mojoAnnotatedClass, Map<String, ComponentAnnotationContent> components,
-        Map<String, MojoAnnotatedClass> mojoAnnotatedClasses )
+            MojoAnnotatedClass mojoAnnotatedClass,
+            Map<String, MojoAnnotatedClass> mojoAnnotatedClasses )
     {
         List<ComponentAnnotationContent> componentAnnotationContents = new ArrayList<>();
 
@@ -725,11 +731,10 @@ public class JavaAnnotationsMojoDescriptorExtractor
         {
             return null;
         }
-        @SuppressWarnings( "unchecked" ) Collection<MavenProject> mavenProjects =
-            project.getProjectReferences().values();
+        Collection<MavenProject> mavenProjects = project.getProjectReferences().values();
         for ( MavenProject mavenProject : mavenProjects )
         {
-            if ( StringUtils.equals( mavenProject.getId(), artifact.getId() ) )
+            if ( Objects.equals( mavenProject.getId(), artifact.getId() ) )
             {
                 return mavenProject;
             }
