@@ -19,6 +19,8 @@ package org.apache.maven.tools.plugin.generator;
  * under the License.
  */
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -39,7 +41,6 @@ import org.apache.maven.project.MavenProject;
 import org.apache.maven.tools.plugin.ExtendedMojoDescriptor;
 import org.apache.maven.tools.plugin.PluginToolsRequest;
 import org.apache.maven.tools.plugin.util.PluginUtils;
-import org.codehaus.plexus.util.IOUtil;
 import org.codehaus.plexus.util.StringUtils;
 import org.codehaus.plexus.util.xml.PrettyPrintXMLWriter;
 import org.codehaus.plexus.util.xml.XMLWriter;
@@ -60,9 +61,7 @@ public class PluginDescriptorGenerator
         this.log = log;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    @Override
     public void execute( File destinationDirectory, PluginToolsRequest request )
         throws GeneratorException
     {
@@ -78,7 +77,7 @@ public class PluginDescriptorGenerator
             // write plugin-help.xml help-descriptor
             MavenProject mavenProject = request.getProject();
 
-            f = new File( mavenProject.getBuild().getOutputDirectory(),
+            f = new File( destinationDirectory,
                           PluginHelpGenerator.getPluginHelpPath( mavenProject ) );
 
             writeDescriptor( f, request, true );
@@ -109,22 +108,14 @@ public class PluginDescriptorGenerator
         {
             destinationFile.delete();
         }
-        else
+        else if ( !destinationFile.getParentFile().exists() )
         {
-            if ( !destinationFile.getParentFile().exists() )
-            {
-                destinationFile.getParentFile().mkdirs();
-            }
+            destinationFile.getParentFile().mkdirs();
         }
 
-        String encoding = "UTF-8";
-
-        Writer writer = null;
-        try
+        try ( Writer writer = new OutputStreamWriter( new FileOutputStream( destinationFile ), UTF_8 ) )
         {
-            writer = new OutputStreamWriter( new FileOutputStream( destinationFile ), encoding );
-
-            XMLWriter w = new PrettyPrintXMLWriter( writer, encoding, null );
+            XMLWriter w = new PrettyPrintXMLWriter( writer, UTF_8.name(), null );
 
             w.writeMarkup( "\n<!-- Generated by maven-plugin-tools " + getVersion() + " -->\n\n" );
 
@@ -154,7 +145,7 @@ public class PluginDescriptorGenerator
 
             if ( pluginDescriptor.getMojos() != null )
             {
-                @SuppressWarnings( "unchecked" ) List<MojoDescriptor> descriptors = pluginDescriptor.getMojos();
+                List<MojoDescriptor> descriptors = pluginDescriptor.getMojos();
 
                 PluginUtils.sortMojos( descriptors );
 
@@ -176,10 +167,6 @@ public class PluginDescriptorGenerator
             writer.flush();
 
         }
-        finally
-        {
-            IOUtil.close( writer );
-        }
     }
 
     protected void processMojoDescriptor( MojoDescriptor mojoDescriptor, XMLWriter w )
@@ -192,6 +179,7 @@ public class PluginDescriptorGenerator
      * @param w              not null
      * @param helpDescriptor will clean html content from description fields
      */
+    @SuppressWarnings( "deprecation" )
     protected void processMojoDescriptor( MojoDescriptor mojoDescriptor, XMLWriter w, boolean helpDescriptor )
     {
         w.startElement( "mojo" );
@@ -413,7 +401,7 @@ public class PluginDescriptorGenerator
         // Parameters
         // ----------------------------------------------------------------------
 
-        @SuppressWarnings( "unchecked" ) List<Parameter> parameters = mojoDescriptor.getParameters();
+        List<Parameter> parameters = mojoDescriptor.getParameters();
 
         w.startElement( "parameters" );
 
